&nbsp;&nbsp;&nbsp;&nbsp;sopt is a simple python optimizer libry.Currentlly,it includes some stochastic optimization
algorithms,like Genetic Algorithm(GA),Particle Swarm Optimization(PSO),Simulated Anealing
(SA),Random Walk(and its improvement version),and some gradient based optimizers,like Gradient
Descent,Momentum,AdaGrad,RMSProp and Adam Optimizers.For the GA optimizers,it includes many
kinds of different selected methods,mutation methods etc,as well as for PSO and other optimizers,
so you can try many different kinds of optimizers with different settings,all the stochastic optimization
also supports the non-linear complex constraints by using penalty methods or dropout-bad-solution methods.

## Please go to [sopt](https://lyrichu.github.io/2018/06/10/sopt-%E4%B8%80%E4%B8%AA%E7%AE%80%E5%8D%95%E7%9A%84python%E6%9C%80%E4%BC%98%E5%8C%96%E5%BA%93/) for more details!
